﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using System.ComponentModel.Design.Serialization;

namespace TypeConvertorControl
{
    public class FullNameConvertor:ExpandableObjectConverter
    {
        public override bool CanConvertFrom(ITypeDescriptorContext context, Type sourceType)
        {
            if (sourceType == typeof(string))
            {
                return true;
            }
            else
            {
                return base.CanConvertFrom(context, sourceType);
            }
        }

        public override bool CanConvertTo(ITypeDescriptorContext context, Type destinationType)
        {
            if (destinationType == typeof(string))
            {
                return true;
            }
            else
            {
                return base.CanConvertTo(context, destinationType);
            }
        }

        public override object ConvertFrom(ITypeDescriptorContext context, System.Globalization.CultureInfo culture, object value)
        {
            if(value is string)
            {
                string[] names = ((string)value).Split(' ');
                if (names.Length == 2)
                {
                    return new FullName(names[0],names[1]);
                }
                else
                {
                    return new FullName();
                }
            }
            else
            {
                return base.ConvertFrom(context,culture,value);
            }
        }

        public override object ConvertTo(ITypeDescriptorContext context, System.Globalization.CultureInfo culture, object value, Type destinationType)
        {
            //if (destinationType == typeof(InstanceDescriptor))
            //{
            //    return new InstanceDescriptor(value.GetType().GetConstructor(new Type[] {typeof(FullName)}),null);
            //}

            if (value is string)
            {
                FullName name = value as FullName;
                return name.FirstName + " " + name.LastName;
            }
            else
            {
                return base.ConvertTo(context, culture, value, destinationType);
            }
        }
    }
}
